@@ -95,7 +95,11 @@ def pack(tx_src, chain_spec):
             tx_src['r'],
             tx_src['s'],
             ]:
-        for b in bytes.fromhex(strip_0x(a)):
+        try:
+            a = strip_0x(a)
+        except TypeError:
+            a = strip_0x(hex(a)) # believe it or not, eth_tester returns signatures as ints not hex
+        for b in bytes.fromhex(a):
             signature[cursor] = b
             cursor += 1
 
@@ -397,11 +401,13 @@ class TxFactory:
         """
         txe = EIP155Transaction(tx, tx['nonce'], tx['chainId'])
         txes = txe.serialize()
+        gas_price = strip_0x(txes['gasPrice'])
+        gas = strip_0x(txes['gas'])
         return {
             'from': tx['from'],
             'to': txes['to'],
-            'gasPrice': '0x' + compact(txes['gasPrice']),
-            'gas': '0x' + compact(txes['gas']),
+            'gasPrice': add_0x(compact(gas_price)),
+            'gas': add_0x(compact(gas)),
             'data': txes['data'],
                 }
 
@@ -423,6 +429,8 @@ class TxFactory:
             return self.build_raw(tx)
         elif tx_format == TxFormat.RAW_ARGS:
             return strip_0x(tx['data'])
+        elif tx_format == TxFormat.DICT:
+            return tx
         raise NotImplementedError('tx formatting {} not implemented'.format(tx_format))
 
 
@@ -569,11 +577,12 @@ class Tx(BaseTx):
         try:
             self.wire = src['raw']
         except KeyError:
-            logg.warning('no inline raw tx src, and no raw rendering implemented, field will be "None"')
+            logg.debug('no inline raw tx src, and no raw rendering implemented, field will be "None"')
 
         self.status = Status.PENDING
         self.logs = None
 
+        self.tx_rcpt_src = None
         if rcpt != None:
             self.apply_receipt(rcpt, strict=strict)
 
@@ -618,6 +627,10 @@ class Tx(BaseTx):
         return self.src()
 
 
+    def rcpt_src(self):
+        return self.tx_rcpt_src
+
+
     def apply_receipt(self, rcpt, strict=False):
         """Apply receipt data to transaction object.
 
@@ -628,6 +641,7 @@ class Tx(BaseTx):
         """
         rcpt = self.src_normalize(rcpt)
         logg.debug('rcpt {}'.format(rcpt))
+        self.tx_rcpt_src = rcpt
 
         tx_hash = add_0x(rcpt['transaction_hash'])
         if rcpt['transaction_hash'] != add_0x(self.hash):
@@ -645,7 +659,7 @@ class Tx(BaseTx):
         except KeyError as e:
             if strict:
                 raise(e)
-            logg.warning('setting "sucess" status on missing status property for {}'.format(self.hash))
+            logg.debug('setting "success" status on missing status property for {}'.format(self.hash))
             status_number = 1
 
         if rcpt['block_number'] == None:
